package cn.com.qmth.examcloud.service.core;

import org.slf4j.MDC;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.autoconfigure.domain.EntityScan;
import org.springframework.boot.autoconfigure.web.MultipartAutoConfiguration;
import org.springframework.cloud.netflix.eureka.EnableEurekaClient;
import org.springframework.cloud.netflix.feign.EnableFeignClients;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.data.jpa.repository.config.EnableJpaRepositories;
import org.springframework.web.multipart.MultipartResolver;
import org.springframework.web.multipart.commons.CommonsMultipartResolver;

import com.qmth.commons.query.dao.impl.BaseQueryDaoImpl;

import cn.com.qmth.examcloud.common.support.logging.ExamCloudLog;
import cn.com.qmth.examcloud.common.support.logging.ExamCloudLogFactory;
import cn.com.qmth.examcloud.common.support.logging.SLF4JImpl;

@ComponentScan(basePackages = { "com.qmth.commons", "cn.com.qmth" })
@EntityScan(basePackages = { "com.qmth.commons", "cn.com.qmth" })
@EnableJpaRepositories(basePackages = { "com.qmth.commons",
		"cn.com.qmth" }, repositoryBaseClass = BaseQueryDaoImpl.class)
@SpringBootApplication
@EnableEurekaClient
@EnableFeignClients
@EnableAutoConfiguration(exclude = { MultipartAutoConfiguration.class })
public class Application {

	private static final ExamCloudLog LOG = ExamCloudLogFactory.getLog(Application.class);

	public static void main(String[] args) throws Exception {

		if (LOG instanceof SLF4JImpl) {
			// 设置主线程埋点跟踪链
			MDC.put("TRACE_ID", Thread.currentThread().getName());
		}
		SpringApplication.run(Application.class, args);
	}

	// 显示声明CommonsMultipartResolver为mutipartResolver
	@Bean(name = "multipartResolver")
	public MultipartResolver multipartResolver() {
		CommonsMultipartResolver resolver = new CommonsMultipartResolver();
		resolver.setDefaultEncoding("UTF-8");
		resolver.setResolveLazily(true);// resolveLazily属性启用是为了推迟文件解析，以在在UploadAction中捕获文件大小异常
		resolver.setMaxInMemorySize(40960);
		resolver.setMaxUploadSize(200 * 1024 * 1024);// 上传文件大小 200M 50*1024*1024
		return resolver;
	}
}
